=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-01-28 21:08:33 +0000
+++ drizzled/drizzled.cc	2011-01-29 23:08:49 +0000
@@ -487,9 +487,13 @@
 {
 
   if (exit_code)
+  {
     errmsg_printf(ERRMSG_LVL_ERROR, _("Aborting\n"));
+  }
   else if (opt_help)
+  {
     usage();
+  }
   clean_up(!opt_help && (exit_code));
   internal::my_end();
   exit(exit_code);
@@ -550,8 +554,8 @@
   }
   if (not user)
   {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Fatal error: Please read \"Security\" section of "
-                      "the manual to find out how to run drizzled as root!\n"));
+    errmsg_printf(ERRMSG_LVL_ERROR, _("Fatal error: Please read \"Security\" section of "
+                                      "the manual to find out how to run drizzled as root!\n"));
     unireg_abort(1);
   }
   if (!strcmp(user,"root"))

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2011-01-28 21:08:33 +0000
+++ drizzled/error.cc	2011-01-29 23:08:49 +0000
@@ -496,9 +496,11 @@
   ADD_ERROR_MESSAGE(ER_TABLE_PERMISSION_DENIED, N_("Permission denied to create '%s'"));
   ADD_ERROR_MESSAGE(ER_TABLE_UNKNOWN, N_("Unknown table '%s'"));
 
+  ADD_ERROR_MESSAGE(ER_SCHEMA_CANNOT_CREATE, N_("Cannot create schema '%s'"));
   ADD_ERROR_MESSAGE(ER_SCHEMA_DOES_NOT_EXIST, N_("Schema does not exist: %s"));
   ADD_ERROR_MESSAGE(ER_ALTER_SCHEMA, N_("Error altering schema: %s"));
   ADD_ERROR_MESSAGE(ER_DROP_SCHEMA, +N_("Error droppping Schema : %s"));
+
   ADD_ERROR_MESSAGE(ER_USE_SQL_BIG_RESULT, N_("Temporary table too large, rerun with SQL_BIG_RESULT."));
   ADD_ERROR_MESSAGE(ER_UNKNOWN_ENGINE_OPTION, N_("Unknown table engine option key/pair %s = %s."));
   ADD_ERROR_MESSAGE(ER_UNKNOWN_SCHEMA_OPTION, N_("Unknown schema engine option key/pair %s = %s."));

=== modified file 'drizzled/error_t.h'
--- drizzled/error_t.h	2011-01-26 21:05:29 +0000
+++ drizzled/error_t.h	2011-01-29 23:08:49 +0000
@@ -858,6 +858,7 @@
   ER_INVALID_TIMESTAMP_VALUE,
   ER_TABLE_UNKNOWN,
 
+  ER_SCHEMA_CANNOT_CREATE,
   ER_PARSE_ERROR_UNKNOWN,
   ER_INVALID_CAST_TO_BOOLEAN,
   ER_INVALID_TIME_VALUE,

=== modified file 'drizzled/generator/schema.h'
--- drizzled/generator/schema.h	2011-01-16 19:48:25 +0000
+++ drizzled/generator/schema.h	2011-01-29 23:08:49 +0000
@@ -21,8 +21,9 @@
 #ifndef DRIZZLED_GENERATOR_SCHEMA_H
 #define DRIZZLED_GENERATOR_SCHEMA_H
 
-#include "drizzled/session.h"
-#include "drizzled/plugin/storage_engine.h"
+#include <drizzled/session.h>
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled {
 namespace generator {
@@ -44,6 +45,13 @@
     while (schema_iterator != schema_names.end())
     {
       identifier::Schema schema_identifier(*schema_iterator);
+
+      if (not plugin::Authorization::isAuthorized(session.user(), schema_identifier, false))
+      {
+        schema_iterator++;
+        continue;
+      }
+
       bool is_schema_parsed= plugin::StorageEngine::getSchemaDefinition(schema_identifier, schema);
       schema_iterator++;
 
@@ -61,6 +69,9 @@
       const drizzled::identifier::Schema *_ptr= &(*schema_iterator);
       schema_iterator++;
 
+      if (not plugin::Authorization::isAuthorized(session.user(), *_ptr, false))
+        continue;
+
       return _ptr;
     }
 

=== modified file 'drizzled/identifier.h'
--- drizzled/identifier.h	2011-01-26 19:15:55 +0000
+++ drizzled/identifier.h	2011-01-29 23:08:49 +0000
@@ -39,11 +39,15 @@
 
 } // namespace drizzled
 
-#include "drizzled/identifier/catalog.h"
-#include "drizzled/identifier/schema.h"
-#include "drizzled/identifier/session.h"
-#include "drizzled/identifier/table.h"
-#include "drizzled/identifier/user.h"
+#include <drizzled/identifier/catalog.h>
+#include <drizzled/identifier/schema.h>
+#include <drizzled/identifier/session.h>
+#include <drizzled/identifier/table.h>
+#include <drizzled/identifier/user.h>
+
+// Constant identifiers user internally
+#include <drizzled/identifier/constants/schema.h>
+#include <drizzled/identifier/constants/table.h>
 
 
 #endif /* DRIZZLED_IDENTIFIER_H */

=== modified file 'drizzled/identifier/catalog.cc'
--- drizzled/identifier/catalog.cc	2011-01-13 02:08:31 +0000
+++ drizzled/identifier/catalog.cc	2011-01-29 23:08:49 +0000
@@ -125,6 +125,12 @@
   return b.getHashValue();
 }
 
+void Catalog::getSQLPath(std::string &sql_path) const
+{
+  sql_path= _name;
+}
+
+
 
 } /* namespace identifier */
 } /* namespace drizzled */

=== modified file 'drizzled/identifier/catalog.h'
--- drizzled/identifier/catalog.h	2011-01-13 02:08:31 +0000
+++ drizzled/identifier/catalog.h	2011-01-29 23:08:49 +0000
@@ -71,6 +71,8 @@
     return _name;
   }
 
+  virtual void getSQLPath(std::string &sql_path) const;
+
   bool isValid() const;
   bool compare(const std::string &arg) const;
 

=== added directory 'drizzled/identifier/constants'
=== added file 'drizzled/identifier/constants/schema.cc'
--- drizzled/identifier/constants/schema.cc	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/constants/schema.cc	2011-01-29 23:08:49 +0000
@@ -0,0 +1,70 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/identifier.h>
+
+namespace drizzled {
+namespace identifier {
+namespace constants {
+
+// Please note, UTF8 id's should not be used with this class
+class Schema : public identifier::Schema
+{
+public:
+  Schema(const std::string &name) :
+    identifier::Schema(name)
+  {
+    std::transform(name.begin(), name.end(), _path.begin(), ::tolower);
+  }
+
+  const std::string &getPath() const
+  {
+    return _path;
+  }
+
+  inline bool isSystem() const
+  {
+    return true;
+  }
+
+private:
+  std::string _path;
+};
+
+} /* namespace constants */
+
+identifier::Schema::const_reference data_dictionary()
+{
+  static drizzled::identifier::Schema _tmp("DATA_DICTIONARY");
+
+  return _tmp;
+}
+
+identifier::Schema::const_reference information_schema()
+{
+  static drizzled::identifier::Schema _tmp("INFORMATION_SCHEMA");
+
+  return _tmp;
+}
+
+} /* namespace identifier */
+} /* namespace drizzled */

=== added file 'drizzled/identifier/constants/schema.h'
--- drizzled/identifier/constants/schema.h	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/constants/schema.h	2011-01-29 23:08:49 +0000
@@ -0,0 +1,37 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_IDENTIFIER_CONSTANTS_SCHEMA_H
+#define DRIZZLED_IDENTIFIER_CONSTANTS_SCHEMA_H
+
+namespace drizzled {
+namespace identifier {
+
+identifier::Schema::const_reference data_dictionary();
+identifier::Schema::const_reference information_schema();
+identifier::Schema::const_reference system_schema();
+
+} /* namespace identifier */
+} /* namespace drizzled */
+
+#define DATA_DICTIONARY_IDENTIFIER drizzled::identifier::data_dictionary()
+#define INFORMATION_SCHEMA_IDENTIFIER drizzled::identifier::information_schema()
+
+#endif /* DRIZZLED_IDENTIFIER_CONSTANTS_SCHEMA_H */

=== added file 'drizzled/identifier/constants/table.cc'
--- drizzled/identifier/constants/table.cc	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/constants/table.cc	2011-01-29 23:08:49 +0000
@@ -0,0 +1,32 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/identifier.h>
+
+namespace drizzled {
+namespace identifier {
+namespace constants {
+
+} /* namespace constants */
+
+} /* namespace identifier */
+} /* namespace drizzled */

=== added file 'drizzled/identifier/constants/table.h'
--- drizzled/identifier/constants/table.h	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/constants/table.h	2011-01-29 23:08:49 +0000
@@ -0,0 +1,31 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_IDENTIFIER_CONSTANTS_TABLE_H
+#define DRIZZLED_IDENTIFIER_CONSTANTS_TABLE_H
+
+namespace drizzled {
+namespace identifier {
+
+
+} /* namespace identifier */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_IDENTIFIER_CONSTANTS_TABLE_H */

=== modified file 'drizzled/identifier/schema.h'
--- drizzled/identifier/schema.h	2011-01-26 19:15:55 +0000
+++ drizzled/identifier/schema.h	2011-01-29 23:08:49 +0000
@@ -82,6 +82,11 @@
 
   virtual bool isValid() const;
 
+  inline virtual bool isSystem() const
+  {
+    return false;
+  }
+
   bool compare(const std::string &arg) const;
   bool compare(Schema::const_reference) const;
 

=== modified file 'drizzled/identifier/table.h'
--- drizzled/identifier/table.h	2011-01-26 19:15:55 +0000
+++ drizzled/identifier/table.h	2011-01-29 23:08:49 +0000
@@ -37,8 +37,6 @@
 #include "drizzled/definitions.h"
 #include "drizzled/message/table.pb.h"
 
-#include "drizzled/identifier.h"
-
 #include <string.h>
 
 #include <assert.h>
@@ -57,7 +55,7 @@
 
 namespace identifier {
 
-class DRIZZLED_API Table : public identifier::Schema
+class DRIZZLED_API Table : public Schema
 {
 public:
   typedef message::Table::TableType Type;

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2011-01-26 19:15:55 +0000
+++ drizzled/include.am	2011-01-29 23:08:49 +0000
@@ -220,6 +220,8 @@
 			      drizzled/hybrid_type_traits_integer.h \
 			      drizzled/identifier.h \
 			      drizzled/identifier/catalog.h \
+			      drizzled/identifier/constants/schema.h \
+			      drizzled/identifier/constants/table.h \
 			      drizzled/identifier/schema.h \
 			      drizzled/identifier/session.h \
 			      drizzled/identifier/table.h \
@@ -669,6 +671,8 @@
 			   drizzled/hybrid_type_traits_integer.cc \
 			   drizzled/identifier.cc \
 			   drizzled/identifier/catalog.cc \
+			   drizzled/identifier/constants/schema.cc \
+			   drizzled/identifier/constants/table.cc \
 			   drizzled/identifier/schema.cc \
 			   drizzled/identifier/table.cc \
 			   drizzled/identifier/user.cc \

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-01-26 01:41:04 +0000
+++ drizzled/main.cc	2011-01-29 23:08:49 +0000
@@ -352,7 +352,9 @@
     {
       currentSession().release();
       currentSession().reset(session.get());
-      transaction_services.sendStartupEvent(*session.get());
+
+
+      transaction_services.sendStartupEvent(*session);
 
       plugin_startup_window(modules, *(session.get()));
     }

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2011-01-26 06:50:16 +0000
+++ drizzled/plugin/storage_engine.cc	2011-01-29 23:08:49 +0000
@@ -686,9 +686,6 @@
 
 void StorageEngine::getIdentifiers(Session &session, const identifier::Schema &schema_identifier, identifier::Table::vector &set_of_identifiers)
 {
-  static identifier::Schema INFORMATION_SCHEMA_IDENTIFIER("INFORMATION_SCHEMA");
-  static identifier::Schema DATA_DICTIONARY_IDENTIFIER("DATA_DICTIONARY");
-
   CachedDirectory directory(schema_identifier.getPath(), set_of_table_definition_ext);
 
   if (schema_identifier == INFORMATION_SCHEMA_IDENTIFIER)

=== modified file 'drizzled/table/cache.cc'
--- drizzled/table/cache.cc	2011-01-17 04:15:23 +0000
+++ drizzled/table/cache.cc	2011-01-29 23:08:49 +0000
@@ -25,7 +25,7 @@
 #include <fcntl.h>
 
 
-#include "drizzled/identifier/table.h"
+#include "drizzled/identifier.h"
 #include "drizzled/table.h"
 #include "drizzled/session.h"
 #include "drizzled/table/concurrent.h"

=== modified file 'drizzled/table/unused.cc'
--- drizzled/table/unused.cc	2010-10-25 19:05:24 +0000
+++ drizzled/table/unused.cc	2011-01-29 23:08:49 +0000
@@ -25,7 +25,7 @@
 #include <fcntl.h>
 
 
-#include "drizzled/identifier/table.h"
+#include "drizzled/identifier.h"
 #include "drizzled/sql_base.h"
 #include "drizzled/set_var.h"
 

=== modified file 'plugin/catalog/tests/r/sql.result'
--- plugin/catalog/tests/r/sql.result	2011-01-13 02:08:31 +0000
+++ plugin/catalog/tests/r/sql.result	2011-01-29 23:08:49 +0000
@@ -1,4 +1,4 @@
 CREATE CATALOG foo;
-ERROR HY000: Permission is denied to create '' catalog.
+ERROR HY000: Permission is denied to create 'foo' catalog.
 DROP CATALOG foo;
-ERROR HY000: Permission is denied to drop '' catalog.
+ERROR HY000: Permission is denied to drop 'foo' catalog.

=== modified file 'plugin/function_engine/function.cc'
--- plugin/function_engine/function.cc	2011-01-26 08:00:35 +0000
+++ plugin/function_engine/function.cc	2011-01-29 23:08:49 +0000
@@ -28,9 +28,6 @@
 using namespace std;
 using namespace drizzled;
 
-static identifier::Schema INFORMATION_SCHEMA_IDENTIFIER("INFORMATION_SCHEMA");
-static identifier::Schema DATA_DICTIONARY_IDENTIFIER("DATA_DICTIONARY");
-
 Function::Function(const std::string &name_arg) :
   drizzled::plugin::StorageEngine(name_arg,
                                   HTON_ALTER_NOT_SUPPORTED |

=== modified file 'plugin/myisam/myisam.h'
--- plugin/myisam/myisam.h	2011-01-17 04:15:23 +0000
+++ plugin/myisam/myisam.h	2011-01-29 23:08:49 +0000
@@ -18,7 +18,7 @@
 #ifndef PLUGIN_MYISAM_MYISAM_H
 #define PLUGIN_MYISAM_MYISAM_H
 
-#include "drizzled/identifier/table.h"
+#include "drizzled/identifier.h"
 
 #include <drizzled/key_map.h>
 

